# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/overload/v2alpha/overload.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,envoy/config/overload/v2alpha/overload.proto\x12\x1d\x65nvoy.config.overload.v2alpha\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x94\x01\n\x0fResourceMonitor\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_type\":\n\x10ThresholdTrigger\x12&\n\x05value\x18\x01 \x01(\x01\x42\x17\xfa\x42\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00\xf0?)\x00\x00\x00\x00\x00\x00\x00\x00\"|\n\x07Trigger\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x44\n\tthreshold\x18\x02 \x01(\x0b\x32/.envoy.config.overload.v2alpha.ThresholdTriggerH\x00\x42\x14\n\rtrigger_oneof\x12\x03\xf8\x42\x01\"k\n\x0eOverloadAction\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x42\n\x08triggers\x18\x02 \x03(\x0b\x32&.envoy.config.overload.v2alpha.TriggerB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\"\xdb\x01\n\x0fOverloadManager\x12\x33\n\x10refresh_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12S\n\x11resource_monitors\x18\x02 \x03(\x0b\x32..envoy.config.overload.v2alpha.ResourceMonitorB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12>\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32-.envoy.config.overload.v2alpha.OverloadActionB\x8c\x01\n+io.envoyproxy.envoy.config.overload.v2alphaB\rOverloadProtoP\x01ZDgithub.com/envoyproxy/go-control-plane/envoy/config/overload/v2alpha\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.overload.v2alpha.overload_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n+io.envoyproxy.envoy.config.overload.v2alphaB\rOverloadProtoP\001ZDgithub.com/envoyproxy/go-control-plane/envoy/config/overload/v2alpha\272\200\310\321\006\002\020\001'
  _RESOURCEMONITOR.fields_by_name['name']._options = None
  _RESOURCEMONITOR.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _RESOURCEMONITOR.fields_by_name['config']._options = None
  _RESOURCEMONITOR.fields_by_name['config']._serialized_options = b'\030\001'
  _THRESHOLDTRIGGER.fields_by_name['value']._options = None
  _THRESHOLDTRIGGER.fields_by_name['value']._serialized_options = b'\372B\024\022\022\031\000\000\000\000\000\000\360?)\000\000\000\000\000\000\000\000'
  _TRIGGER.oneofs_by_name['trigger_oneof']._options = None
  _TRIGGER.oneofs_by_name['trigger_oneof']._serialized_options = b'\370B\001'
  _TRIGGER.fields_by_name['name']._options = None
  _TRIGGER.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _OVERLOADACTION.fields_by_name['name']._options = None
  _OVERLOADACTION.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _OVERLOADACTION.fields_by_name['triggers']._options = None
  _OVERLOADACTION.fields_by_name['triggers']._serialized_options = b'\372B\005\222\001\002\010\001'
  _OVERLOADMANAGER.fields_by_name['resource_monitors']._options = None
  _OVERLOADMANAGER.fields_by_name['resource_monitors']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_RESOURCEMONITOR']._serialized_start=225
  _globals['_RESOURCEMONITOR']._serialized_end=373
  _globals['_THRESHOLDTRIGGER']._serialized_start=375
  _globals['_THRESHOLDTRIGGER']._serialized_end=433
  _globals['_TRIGGER']._serialized_start=435
  _globals['_TRIGGER']._serialized_end=559
  _globals['_OVERLOADACTION']._serialized_start=561
  _globals['_OVERLOADACTION']._serialized_end=668
  _globals['_OVERLOADMANAGER']._serialized_start=671
  _globals['_OVERLOADMANAGER']._serialized_end=890
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/thrift_proxy/filters/payload_to_metadata/v3/payload_to_metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher.v3 import regex_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_regex__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nfenvoy/extensions/filters/network/thrift_proxy/filters/payload_to_metadata/v3/payload_to_metadata.proto\x12Lenvoy.extensions.filters.network.thrift_proxy.filters.payload_to_metadata.v3\x1a!envoy/type/matcher/v3/regex.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa6\t\n\x11PayloadToMetadata\x12\x85\x01\n\rrequest_rules\x18\x01 \x03(\x0b\x32\x64.envoy.extensions.filters.network.thrift_proxy.filters.payload_to_metadata.v3.PayloadToMetadata.RuleB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\xb2\x02\n\x0cKeyValuePair\x12\x1a\n\x12metadata_namespace\x18\x01 \x01(\t\x12\x14\n\x03key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0f\n\x05value\x18\x03 \x01(\tH\x00\x12M\n\x13regex_value_rewrite\x18\x04 \x01(\x0b\x32..envoy.type.matcher.v3.RegexMatchAndSubstituteH\x00\x12\x81\x01\n\x04type\x18\x05 \x01(\x0e\x32i.envoy.extensions.filters.network.thrift_proxy.filters.payload_to_metadata.v3.PayloadToMetadata.ValueTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x42\x0c\n\nvalue_type\x1a\xe5\x03\n\x04Rule\x12\x15\n\x0bmethod_name\x18\x01 \x01(\tH\x00\x12\x16\n\x0cservice_name\x18\x02 \x01(\tH\x00\x12\x8f\x01\n\x0e\x66ield_selector\x18\x03 \x01(\x0b\x32m.envoy.extensions.filters.network.thrift_proxy.filters.payload_to_metadata.v3.PayloadToMetadata.FieldSelectorB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x80\x01\n\non_present\x18\x04 \x01(\x0b\x32l.envoy.extensions.filters.network.thrift_proxy.filters.payload_to_metadata.v3.PayloadToMetadata.KeyValuePair\x12\x80\x01\n\non_missing\x18\x05 \x01(\x0b\x32l.envoy.extensions.filters.network.thrift_proxy.filters.payload_to_metadata.v3.PayloadToMetadata.KeyValuePairB\x16\n\x0fmatch_specifier\x12\x03\xf8\x42\x01\x1a\xc6\x01\n\rFieldSelector\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12 \n\x02id\x18\x02 \x01(\x05\x42\x14\xfa\x42\x11\x1a\x0f\x18\xff\xff\x01(\x80\x80\xfe\xff\xff\xff\xff\xff\xff\x01\x12|\n\x05\x63hild\x18\x03 \x01(\x0b\x32m.envoy.extensions.filters.network.thrift_proxy.filters.payload_to_metadata.v3.PayloadToMetadata.FieldSelector\"#\n\tValueType\x12\n\n\x06STRING\x10\x00\x12\n\n\x06NUMBER\x10\x01\x42\x8a\x02\nZio.envoyproxy.envoy.extensions.filters.network.thrift_proxy.filters.payload_to_metadata.v3B\x16PayloadToMetadataProtoP\x01Z\x89\x01github.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/thrift_proxy/filters/payload_to_metadata/v3;payload_to_metadatav3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.thrift_proxy.filters.payload_to_metadata.v3.payload_to_metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nZio.envoyproxy.envoy.extensions.filters.network.thrift_proxy.filters.payload_to_metadata.v3B\026PayloadToMetadataProtoP\001Z\211\001github.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/thrift_proxy/filters/payload_to_metadata/v3;payload_to_metadatav3\272\200\310\321\006\002\020\002'
  _PAYLOADTOMETADATA_KEYVALUEPAIR.fields_by_name['key']._options = None
  _PAYLOADTOMETADATA_KEYVALUEPAIR.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _PAYLOADTOMETADATA_KEYVALUEPAIR.fields_by_name['type']._options = None
  _PAYLOADTOMETADATA_KEYVALUEPAIR.fields_by_name['type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _PAYLOADTOMETADATA_RULE.oneofs_by_name['match_specifier']._options = None
  _PAYLOADTOMETADATA_RULE.oneofs_by_name['match_specifier']._serialized_options = b'\370B\001'
  _PAYLOADTOMETADATA_RULE.fields_by_name['field_selector']._options = None
  _PAYLOADTOMETADATA_RULE.fields_by_name['field_selector']._serialized_options = b'\372B\005\212\001\002\020\001'
  _PAYLOADTOMETADATA_FIELDSELECTOR.fields_by_name['name']._options = None
  _PAYLOADTOMETADATA_FIELDSELECTOR.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _PAYLOADTOMETADATA_FIELDSELECTOR.fields_by_name['id']._options = None
  _PAYLOADTOMETADATA_FIELDSELECTOR.fields_by_name['id']._serialized_options = b'\372B\021\032\017\030\377\377\001(\200\200\376\377\377\377\377\377\377\001'
  _PAYLOADTOMETADATA.fields_by_name['request_rules']._options = None
  _PAYLOADTOMETADATA.fields_by_name['request_rules']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_PAYLOADTOMETADATA']._serialized_start=276
  _globals['_PAYLOADTOMETADATA']._serialized_end=1466
  _globals['_PAYLOADTOMETADATA_KEYVALUEPAIR']._serialized_start=434
  _globals['_PAYLOADTOMETADATA_KEYVALUEPAIR']._serialized_end=740
  _globals['_PAYLOADTOMETADATA_RULE']._serialized_start=743
  _globals['_PAYLOADTOMETADATA_RULE']._serialized_end=1228
  _globals['_PAYLOADTOMETADATA_FIELDSELECTOR']._serialized_start=1231
  _globals['_PAYLOADTOMETADATA_FIELDSELECTOR']._serialized_end=1429
  _globals['_PAYLOADTOMETADATA_VALUETYPE']._serialized_start=1431
  _globals['_PAYLOADTOMETADATA_VALUETYPE']._serialized_end=1466
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/transport_sockets/tls/v3/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6envoy/extensions/transport_sockets/tls/v3/common.proto\x12)envoy.extensions.transport_sockets.tls.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a$envoy/config/core/v3/extension.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xbe\x03\n\rTlsParameters\x12t\n\x1ctls_minimum_protocol_version\x18\x01 \x01(\x0e\x32\x44.envoy.extensions.transport_sockets.tls.v3.TlsParameters.TlsProtocolB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12t\n\x1ctls_maximum_protocol_version\x18\x02 \x01(\x0e\x32\x44.envoy.extensions.transport_sockets.tls.v3.TlsParameters.TlsProtocolB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x15\n\rcipher_suites\x18\x03 \x03(\t\x12\x13\n\x0b\x65\x63\x64h_curves\x18\x04 \x03(\t\x12\x1c\n\x14signature_algorithms\x18\x05 \x03(\t\"O\n\x0bTlsProtocol\x12\x0c\n\x08TLS_AUTO\x10\x00\x12\x0b\n\x07TLSv1_0\x10\x01\x12\x0b\n\x07TLSv1_1\x10\x02\x12\x0b\n\x07TLSv1_2\x10\x03\x12\x0b\n\x07TLSv1_3\x10\x04:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.api.v2.auth.TlsParameters\"\xb4\x01\n\x12PrivateKeyProvider\x12\x1e\n\rprovider_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x34\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB\x06\xb8\xb7\x8b\xa4\x02\x01H\x00:+\x9a\xc5\x88\x1e&\n$envoy.api.v2.auth.PrivateKeyProviderB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfig\"\xca\x04\n\x0eTlsCertificate\x12;\n\x11\x63\x65rtificate_chain\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12=\n\x0bprivate_key\x18\x02 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x38\n\x06pkcs12\x18\x08 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x41\n\x11watched_directory\x18\x07 \x01(\x0b\x32&.envoy.config.core.v3.WatchedDirectory\x12[\n\x14private_key_provider\x18\x06 \x01(\x0b\x32=.envoy.extensions.transport_sockets.tls.v3.PrivateKeyProvider\x12:\n\x08password\x18\x03 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x35\n\x0bocsp_staple\x18\x04 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12\x46\n\x1csigned_certificate_timestamp\x18\x05 \x03(\x0b\x32 .envoy.config.core.v3.DataSource:\'\x9a\xc5\x88\x1e\"\n envoy.api.v2.auth.TlsCertificate\"\x85\x01\n\x14TlsSessionTicketKeys\x12>\n\x04keys\x18\x01 \x03(\x0b\x32 .envoy.config.core.v3.DataSourceB\x0e\xfa\x42\x05\x92\x01\x02\x08\x01\xb8\xb7\x8b\xa4\x02\x01:-\x9a\xc5\x88\x1e(\n&envoy.api.v2.auth.TlsSessionTicketKeys\"T\n!CertificateProviderPluginInstance\x12\x15\n\rinstance_name\x18\x01 \x01(\t\x12\x18\n\x10\x63\x65rtificate_name\x18\x02 \x01(\t\"\x92\x02\n\x15SubjectAltNameMatcher\x12\x66\n\x08san_type\x18\x01 \x01(\x0e\x32H.envoy.extensions.transport_sockets.tls.v3.SubjectAltNameMatcher.SanTypeB\n\xfa\x42\x07\x82\x01\x04\x10\x01 \x00\x12?\n\x07matcher\x18\x02 \x01(\x0b\x32$.envoy.type.matcher.v3.StringMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"P\n\x07SanType\x12\x18\n\x14SAN_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05\x45MAIL\x10\x01\x12\x07\n\x03\x44NS\x10\x02\x12\x07\n\x03URI\x10\x03\x12\x0e\n\nIP_ADDRESS\x10\x04\"\xdd\t\n\x1c\x43\x65rtificateValidationContext\x12L\n\ntrusted_ca\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x16\xf2\x98\xfe\x8f\x05\x10\x12\x0e\x63\x61_cert_source\x12\x8e\x01\n ca_certificate_provider_instance\x18\r \x01(\x0b\x32L.envoy.extensions.transport_sockets.tls.v3.CertificateProviderPluginInstanceB\x16\xf2\x98\xfe\x8f\x05\x10\x12\x0e\x63\x61_cert_source\x12\x41\n\x11watched_directory\x18\x0b \x01(\x0b\x32&.envoy.config.core.v3.WatchedDirectory\x12/\n\x17verify_certificate_spki\x18\x03 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\"\x06r\x04\x10,(,\x12/\n\x17verify_certificate_hash\x18\x02 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\"\x06r\x04\x10@(_\x12g\n\x1dmatch_typed_subject_alt_names\x18\x0f \x03(\x0b\x32@.envoy.extensions.transport_sockets.tls.v3.SubjectAltNameMatcher\x12R\n\x17match_subject_alt_names\x18\t \x03(\x0b\x32$.envoy.type.matcher.v3.StringMatcherB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12H\n$require_signed_certificate_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12-\n\x03\x63rl\x18\x07 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12!\n\x19\x61llow_expired_certificate\x18\x08 \x01(\x08\x12\x8a\x01\n\x18trust_chain_verification\x18\n \x01(\x0e\x32^.envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.TrustChainVerificationB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12K\n\x17\x63ustom_validator_config\x18\x0c \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12!\n\x19only_verify_leaf_cert_crl\x18\x0e \x01(\x08\x12?\n\x10max_verify_depth\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\"F\n\x16TrustChainVerification\x12\x16\n\x12VERIFY_TRUST_CHAIN\x10\x00\x12\x14\n\x10\x41\x43\x43\x45PT_UNTRUSTED\x10\x01:5\x9a\xc5\x88\x1e\x30\n.envoy.api.v2.auth.CertificateValidationContextJ\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06R\x17verify_subject_alt_nameB\xa8\x01\n7io.envoyproxy.envoy.extensions.transport_sockets.tls.v3B\x0b\x43ommonProtoP\x01ZVgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/tls/v3;tlsv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.transport_sockets.tls.v3.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7io.envoyproxy.envoy.extensions.transport_sockets.tls.v3B\013CommonProtoP\001ZVgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/tls/v3;tlsv3\272\200\310\321\006\002\020\002'
  _TLSPARAMETERS.fields_by_name['tls_minimum_protocol_version']._options = None
  _TLSPARAMETERS.fields_by_name['tls_minimum_protocol_version']._serialized_options = b'\372B\005\202\001\002\020\001'
  _TLSPARAMETERS.fields_by_name['tls_maximum_protocol_version']._options = None
  _TLSPARAMETERS.fields_by_name['tls_maximum_protocol_version']._serialized_options = b'\372B\005\202\001\002\020\001'
  _TLSPARAMETERS._options = None
  _TLSPARAMETERS._serialized_options = b'\232\305\210\036!\n\037envoy.api.v2.auth.TlsParameters'
  _PRIVATEKEYPROVIDER.fields_by_name['provider_name']._options = None
  _PRIVATEKEYPROVIDER.fields_by_name['provider_name']._serialized_options = b'\372B\004r\002\020\001'
  _PRIVATEKEYPROVIDER.fields_by_name['typed_config']._options = None
  _PRIVATEKEYPROVIDER.fields_by_name['typed_config']._serialized_options = b'\270\267\213\244\002\001'
  _PRIVATEKEYPROVIDER._options = None
  _PRIVATEKEYPROVIDER._serialized_options = b'\232\305\210\036&\n$envoy.api.v2.auth.PrivateKeyProvider'
  _TLSCERTIFICATE.fields_by_name['private_key']._options = None
  _TLSCERTIFICATE.fields_by_name['private_key']._serialized_options = b'\270\267\213\244\002\001'
  _TLSCERTIFICATE.fields_by_name['pkcs12']._options = None
  _TLSCERTIFICATE.fields_by_name['pkcs12']._serialized_options = b'\270\267\213\244\002\001'
  _TLSCERTIFICATE.fields_by_name['password']._options = None
  _TLSCERTIFICATE.fields_by_name['password']._serialized_options = b'\270\267\213\244\002\001'
  _TLSCERTIFICATE._options = None
  _TLSCERTIFICATE._serialized_options = b'\232\305\210\036\"\n envoy.api.v2.auth.TlsCertificate'
  _TLSSESSIONTICKETKEYS.fields_by_name['keys']._options = None
  _TLSSESSIONTICKETKEYS.fields_by_name['keys']._serialized_options = b'\372B\005\222\001\002\010\001\270\267\213\244\002\001'
  _TLSSESSIONTICKETKEYS._options = None
  _TLSSESSIONTICKETKEYS._serialized_options = b'\232\305\210\036(\n&envoy.api.v2.auth.TlsSessionTicketKeys'
  _SUBJECTALTNAMEMATCHER.fields_by_name['san_type']._options = None
  _SUBJECTALTNAMEMATCHER.fields_by_name['san_type']._serialized_options = b'\372B\007\202\001\004\020\001 \000'
  _SUBJECTALTNAMEMATCHER.fields_by_name['matcher']._options = None
  _SUBJECTALTNAMEMATCHER.fields_by_name['matcher']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['trusted_ca']._options = None
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['trusted_ca']._serialized_options = b'\362\230\376\217\005\020\022\016ca_cert_source'
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['ca_certificate_provider_instance']._options = None
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['ca_certificate_provider_instance']._serialized_options = b'\362\230\376\217\005\020\022\016ca_cert_source'
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['verify_certificate_spki']._options = None
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['verify_certificate_spki']._serialized_options = b'\372B\013\222\001\010\"\006r\004\020,(,'
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['verify_certificate_hash']._options = None
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['verify_certificate_hash']._serialized_options = b'\372B\013\222\001\010\"\006r\004\020@(_'
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['match_subject_alt_names']._options = None
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['match_subject_alt_names']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['trust_chain_verification']._options = None
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['trust_chain_verification']._serialized_options = b'\372B\005\202\001\002\020\001'
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['max_verify_depth']._options = None
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['max_verify_depth']._serialized_options = b'\372B\004*\002\030d'
  _CERTIFICATEVALIDATIONCONTEXT._options = None
  _CERTIFICATEVALIDATIONCONTEXT._serialized_options = b'\232\305\210\0360\n.envoy.api.v2.auth.CertificateValidationContext'
  _globals['_TLSPARAMETERS']._serialized_start=462
  _globals['_TLSPARAMETERS']._serialized_end=908
  _globals['_TLSPARAMETERS_TLSPROTOCOL']._serialized_start=789
  _globals['_TLSPARAMETERS_TLSPROTOCOL']._serialized_end=868
  _globals['_PRIVATEKEYPROVIDER']._serialized_start=911
  _globals['_PRIVATEKEYPROVIDER']._serialized_end=1091
  _globals['_TLSCERTIFICATE']._serialized_start=1094
  _globals['_TLSCERTIFICATE']._serialized_end=1680
  _globals['_TLSSESSIONTICKETKEYS']._serialized_start=1683
  _globals['_TLSSESSIONTICKETKEYS']._serialized_end=1816
  _globals['_CERTIFICATEPROVIDERPLUGININSTANCE']._serialized_start=1818
  _globals['_CERTIFICATEPROVIDERPLUGININSTANCE']._serialized_end=1902
  _globals['_SUBJECTALTNAMEMATCHER']._serialized_start=1905
  _globals['_SUBJECTALTNAMEMATCHER']._serialized_end=2179
  _globals['_SUBJECTALTNAMEMATCHER_SANTYPE']._serialized_start=2099
  _globals['_SUBJECTALTNAMEMATCHER_SANTYPE']._serialized_end=2179
  _globals['_CERTIFICATEVALIDATIONCONTEXT']._serialized_start=2182
  _globals['_CERTIFICATEVALIDATIONCONTEXT']._serialized_end=3427
  _globals['_CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION']._serialized_start=3265
  _globals['_CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION']._serialized_end=3335
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/servicecontrol/v1/service_controller.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api.servicecontrol.v1 import check_error_pb2 as google_dot_api_dot_servicecontrol_dot_v1_dot_check__error__pb2
from google.api.servicecontrol.v1 import operation_pb2 as google_dot_api_dot_servicecontrol_dot_v1_dot_operation__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5google/api/servicecontrol/v1/service_controller.proto\x12\x1cgoogle.api.servicecontrol.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a.google/api/servicecontrol/v1/check_error.proto\x1a,google/api/servicecontrol/v1/operation.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto\"{\n\x0c\x43heckRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12:\n\toperation\x18\x02 \x01(\x0b\x32\'.google.api.servicecontrol.v1.Operation\x12\x19\n\x11service_config_id\x18\x04 \x01(\t\"\xe6\x04\n\rCheckResponse\x12\x14\n\x0coperation_id\x18\x01 \x01(\t\x12>\n\x0c\x63heck_errors\x18\x02 \x03(\x0b\x32(.google.api.servicecontrol.v1.CheckError\x12\x19\n\x11service_config_id\x18\x05 \x01(\t\x12\x1a\n\x12service_rollout_id\x18\x0b \x01(\t\x12I\n\ncheck_info\x18\x06 \x01(\x0b\x32\x35.google.api.servicecontrol.v1.CheckResponse.CheckInfo\x1av\n\tCheckInfo\x12\x18\n\x10unused_arguments\x18\x01 \x03(\t\x12O\n\rconsumer_info\x18\x02 \x01(\x0b\x32\x38.google.api.servicecontrol.v1.CheckResponse.ConsumerInfo\x1a\x84\x02\n\x0c\x43onsumerInfo\x12\x16\n\x0eproject_number\x18\x01 \x01(\x03\x12S\n\x04type\x18\x02 \x01(\x0e\x32\x45.google.api.servicecontrol.v1.CheckResponse.ConsumerInfo.ConsumerType\x12\x17\n\x0f\x63onsumer_number\x18\x03 \x01(\x03\"n\n\x0c\x43onsumerType\x12\x1d\n\x19\x43ONSUMER_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PROJECT\x10\x01\x12\n\n\x06\x46OLDER\x10\x02\x12\x10\n\x0cORGANIZATION\x10\x03\x12\x14\n\x10SERVICE_SPECIFIC\x10\x04\"}\n\rReportRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12;\n\noperations\x18\x02 \x03(\x0b\x32\'.google.api.servicecontrol.v1.Operation\x12\x19\n\x11service_config_id\x18\x03 \x01(\t\"\xe1\x01\n\x0eReportResponse\x12O\n\rreport_errors\x18\x01 \x03(\x0b\x32\x38.google.api.servicecontrol.v1.ReportResponse.ReportError\x12\x19\n\x11service_config_id\x18\x02 \x01(\t\x12\x1a\n\x12service_rollout_id\x18\x04 \x01(\t\x1aG\n\x0bReportError\x12\x14\n\x0coperation_id\x18\x01 \x01(\t\x12\"\n\x06status\x18\x02 \x01(\x0b\x32\x12.google.rpc.Status2\xbc\x03\n\x11ServiceController\x12\x8e\x01\n\x05\x43heck\x12*.google.api.servicecontrol.v1.CheckRequest\x1a+.google.api.servicecontrol.v1.CheckResponse\",\x82\xd3\xe4\x93\x02&\"!/v1/services/{service_name}:check:\x01*\x12\x92\x01\n\x06Report\x12+.google.api.servicecontrol.v1.ReportRequest\x1a,.google.api.servicecontrol.v1.ReportResponse\"-\x82\xd3\xe4\x93\x02\'\"\"/v1/services/{service_name}:report:\x01*\x1a\x80\x01\xca\x41\x1dservicecontrol.googleapis.com\xd2\x41]https://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/servicecontrolB\xf8\x01\n com.google.api.servicecontrol.v1B\x16ServiceControllerProtoP\x01ZJgoogle.golang.org/genproto/googleapis/api/servicecontrol/v1;servicecontrol\xf8\x01\x01\xa2\x02\x04GASC\xaa\x02\x1eGoogle.Cloud.ServiceControl.V1\xca\x02\x1eGoogle\\Cloud\\ServiceControl\\V1\xea\x02!Google::Cloud::ServiceControl::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.servicecontrol.v1.service_controller_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n com.google.api.servicecontrol.v1B\026ServiceControllerProtoP\001ZJgoogle.golang.org/genproto/googleapis/api/servicecontrol/v1;servicecontrol\370\001\001\242\002\004GASC\252\002\036Google.Cloud.ServiceControl.V1\312\002\036Google\\Cloud\\ServiceControl\\V1\352\002!Google::Cloud::ServiceControl::V1'
  _SERVICECONTROLLER._options = None
  _SERVICECONTROLLER._serialized_options = b'\312A\035servicecontrol.googleapis.com\322A]https://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/servicecontrol'
  _SERVICECONTROLLER.methods_by_name['Check']._options = None
  _SERVICECONTROLLER.methods_by_name['Check']._serialized_options = b'\202\323\344\223\002&\"!/v1/services/{service_name}:check:\001*'
  _SERVICECONTROLLER.methods_by_name['Report']._options = None
  _SERVICECONTROLLER.methods_by_name['Report']._serialized_options = b'\202\323\344\223\002\'\"\"/v1/services/{service_name}:report:\001*'
  _globals['_CHECKREQUEST']._serialized_start=294
  _globals['_CHECKREQUEST']._serialized_end=417
  _globals['_CHECKRESPONSE']._serialized_start=420
  _globals['_CHECKRESPONSE']._serialized_end=1034
  _globals['_CHECKRESPONSE_CHECKINFO']._serialized_start=653
  _globals['_CHECKRESPONSE_CHECKINFO']._serialized_end=771
  _globals['_CHECKRESPONSE_CONSUMERINFO']._serialized_start=774
  _globals['_CHECKRESPONSE_CONSUMERINFO']._serialized_end=1034
  _globals['_CHECKRESPONSE_CONSUMERINFO_CONSUMERTYPE']._serialized_start=924
  _globals['_CHECKRESPONSE_CONSUMERINFO_CONSUMERTYPE']._serialized_end=1034
  _globals['_REPORTREQUEST']._serialized_start=1036
  _globals['_REPORTREQUEST']._serialized_end=1161
  _globals['_REPORTRESPONSE']._serialized_start=1164
  _globals['_REPORTRESPONSE']._serialized_end=1389
  _globals['_REPORTRESPONSE_REPORTERROR']._serialized_start=1318
  _globals['_REPORTRESPONSE_REPORTERROR']._serialized_end=1389
  _globals['_SERVICECONTROLLER']._serialized_start=1392
  _globals['_SERVICECONTROLLER']._serialized_end=1836
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/trace/v2/zipkin.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"envoy/config/trace/v2/zipkin.proto\x12\x15\x65nvoy.config.trace.v2\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xec\x02\n\x0cZipkinConfig\x12\"\n\x11\x63ollector_cluster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12#\n\x12\x63ollector_endpoint\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x17\n\x0ftrace_id_128bit\x18\x03 \x01(\x08\x12\x37\n\x13shared_span_context\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12`\n\x1a\x63ollector_endpoint_version\x18\x05 \x01(\x0e\x32<.envoy.config.trace.v2.ZipkinConfig.CollectorEndpointVersion\"_\n\x18\x43ollectorEndpointVersion\x12\x1a\n\x0cHTTP_JSON_V1\x10\x00\x1a\x08\x08\x01\xa8\xf7\xb4\x8b\x02\x01\x12\r\n\tHTTP_JSON\x10\x01\x12\x0e\n\nHTTP_PROTO\x10\x02\x12\x08\n\x04GRPC\x10\x03\x42\x82\x01\n#io.envoyproxy.envoy.config.trace.v2B\x0bZipkinProtoP\x01ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v2;tracev2\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.trace.v2.zipkin_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.config.trace.v2B\013ZipkinProtoP\001ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v2;tracev2\272\200\310\321\006\002\020\001'
  _ZIPKINCONFIG_COLLECTORENDPOINTVERSION.values_by_name["HTTP_JSON_V1"]._options = None
  _ZIPKINCONFIG_COLLECTORENDPOINTVERSION.values_by_name["HTTP_JSON_V1"]._serialized_options = b'\010\001\250\367\264\213\002\001'
  _ZIPKINCONFIG.fields_by_name['collector_cluster']._options = None
  _ZIPKINCONFIG.fields_by_name['collector_cluster']._serialized_options = b'\372B\004r\002 \001'
  _ZIPKINCONFIG.fields_by_name['collector_endpoint']._options = None
  _ZIPKINCONFIG.fields_by_name['collector_endpoint']._serialized_options = b'\372B\004r\002 \001'
  _globals['_ZIPKINCONFIG']._serialized_start=187
  _globals['_ZIPKINCONFIG']._serialized_end=551
  _globals['_ZIPKINCONFIG_COLLECTORENDPOINTVERSION']._serialized_start=456
  _globals['_ZIPKINCONFIG_COLLECTORENDPOINTVERSION']._serialized_end=551
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/load_balancing_policies/common/v3/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?envoy/extensions/load_balancing_policies/common/v3/common.proto\x12\x32\x65nvoy.extensions.load_balancing_policies.common.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xed\x03\n\x10LocalityLbConfig\x12v\n\x14zone_aware_lb_config\x18\x01 \x01(\x0b\x32V.envoy.extensions.load_balancing_policies.common.v3.LocalityLbConfig.ZoneAwareLbConfigH\x00\x12\x84\x01\n\x1blocality_weighted_lb_config\x18\x02 \x01(\x0b\x32].envoy.extensions.load_balancing_policies.common.v3.LocalityLbConfig.LocalityWeightedLbConfigH\x00\x1a\x9b\x01\n\x11ZoneAwareLbConfig\x12/\n\x0frouting_enabled\x18\x01 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x12\x36\n\x10min_cluster_size\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x1d\n\x15\x66\x61il_traffic_on_panic\x18\x03 \x01(\x08\x1a\x1a\n\x18LocalityWeightedLbConfigB \n\x19locality_config_specifier\x12\x03\xf8\x42\x01\"\xb4\x01\n\x0fSlowStartConfig\x12\x34\n\x11slow_start_window\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x37\n\naggression\x18\x02 \x01(\x0b\x32#.envoy.config.core.v3.RuntimeDouble\x12\x32\n\x12min_weight_percent\x18\x03 \x01(\x0b\x32\x16.envoy.type.v3.Percent\"\x81\x01\n\x19\x43onsistentHashingLbConfig\x12 \n\x18use_hostname_for_hashing\x18\x01 \x01(\x08\x12\x42\n\x13hash_balance_factor\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(dB\xbd\x01\n@io.envoyproxy.envoy.extensions.load_balancing_policies.common.v3B\x0b\x43ommonProtoP\x01Zbgithub.com/envoyproxy/go-control-plane/envoy/extensions/load_balancing_policies/common/v3;commonv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.load_balancing_policies.common.v3.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n@io.envoyproxy.envoy.extensions.load_balancing_policies.common.v3B\013CommonProtoP\001Zbgithub.com/envoyproxy/go-control-plane/envoy/extensions/load_balancing_policies/common/v3;commonv3\272\200\310\321\006\002\020\002'
  _LOCALITYLBCONFIG.oneofs_by_name['locality_config_specifier']._options = None
  _LOCALITYLBCONFIG.oneofs_by_name['locality_config_specifier']._serialized_options = b'\370B\001'
  _CONSISTENTHASHINGLBCONFIG.fields_by_name['hash_balance_factor']._options = None
  _CONSISTENTHASHINGLBCONFIG.fields_by_name['hash_balance_factor']._serialized_options = b'\372B\004*\002(d'
  _globals['_LOCALITYLBCONFIG']._serialized_start=302
  _globals['_LOCALITYLBCONFIG']._serialized_end=795
  _globals['_LOCALITYLBCONFIG_ZONEAWARELBCONFIG']._serialized_start=578
  _globals['_LOCALITYLBCONFIG_ZONEAWARELBCONFIG']._serialized_end=733
  _globals['_LOCALITYLBCONFIG_LOCALITYWEIGHTEDLBCONFIG']._serialized_start=735
  _globals['_LOCALITYLBCONFIG_LOCALITYWEIGHTEDLBCONFIG']._serialized_end=761
  _globals['_SLOWSTARTCONFIG']._serialized_start=798
  _globals['_SLOWSTARTCONFIG']._serialized_end=978
  _globals['_CONSISTENTHASHINGLBCONFIG']._serialized_start=981
  _globals['_CONSISTENTHASHINGLBCONFIG']._serialized_end=1110
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/data/orca/v3/orca_load_report.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'xds/data/orca/v3/orca_load_report.proto\x12\x10xds.data.orca.v3\x1a\x17validate/validate.proto\"\x89\x05\n\x0eOrcaLoadReport\x12\'\n\x0f\x63pu_utilization\x18\x01 \x01(\x01\x42\x0e\xfa\x42\x0b\x12\t)\x00\x00\x00\x00\x00\x00\x00\x00\x12\x30\n\x0fmem_utilization\x18\x02 \x01(\x01\x42\x17\xfa\x42\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00\xf0?)\x00\x00\x00\x00\x00\x00\x00\x00\x12\x0f\n\x03rps\x18\x03 \x01(\x04\x42\x02\x18\x01\x12G\n\x0crequest_cost\x18\x04 \x03(\x0b\x32\x31.xds.data.orca.v3.OrcaLoadReport.RequestCostEntry\x12\x64\n\x0butilization\x18\x05 \x03(\x0b\x32\x31.xds.data.orca.v3.OrcaLoadReport.UtilizationEntryB\x1c\xfa\x42\x19\x9a\x01\x16*\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00\xf0?)\x00\x00\x00\x00\x00\x00\x00\x00\x12&\n\x0erps_fractional\x18\x06 \x01(\x01\x42\x0e\xfa\x42\x0b\x12\t)\x00\x00\x00\x00\x00\x00\x00\x00\x12\x1b\n\x03\x65ps\x18\x07 \x01(\x01\x42\x0e\xfa\x42\x0b\x12\t)\x00\x00\x00\x00\x00\x00\x00\x00\x12I\n\rnamed_metrics\x18\x08 \x03(\x0b\x32\x32.xds.data.orca.v3.OrcaLoadReport.NamedMetricsEntry\x12/\n\x17\x61pplication_utilization\x18\t \x01(\x01\x42\x0e\xfa\x42\x0b\x12\t)\x00\x00\x00\x00\x00\x00\x00\x00\x1a\x32\n\x10RequestCostEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1a\x32\n\x10UtilizationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1a\x33\n\x11NamedMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x42]\n\x1b\x63om.github.xds.data.orca.v3B\x13OrcaLoadReportProtoP\x01Z\'github.com/cncf/xds/go/xds/data/orca/v3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xds.data.orca.v3.orca_load_report_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.github.xds.data.orca.v3B\023OrcaLoadReportProtoP\001Z\'github.com/cncf/xds/go/xds/data/orca/v3'
  _ORCALOADREPORT_REQUESTCOSTENTRY._options = None
  _ORCALOADREPORT_REQUESTCOSTENTRY._serialized_options = b'8\001'
  _ORCALOADREPORT_UTILIZATIONENTRY._options = None
  _ORCALOADREPORT_UTILIZATIONENTRY._serialized_options = b'8\001'
  _ORCALOADREPORT_NAMEDMETRICSENTRY._options = None
  _ORCALOADREPORT_NAMEDMETRICSENTRY._serialized_options = b'8\001'
  _ORCALOADREPORT.fields_by_name['cpu_utilization']._options = None
  _ORCALOADREPORT.fields_by_name['cpu_utilization']._serialized_options = b'\372B\013\022\t)\000\000\000\000\000\000\000\000'
  _ORCALOADREPORT.fields_by_name['mem_utilization']._options = None
  _ORCALOADREPORT.fields_by_name['mem_utilization']._serialized_options = b'\372B\024\022\022\031\000\000\000\000\000\000\360?)\000\000\000\000\000\000\000\000'
  _ORCALOADREPORT.fields_by_name['rps']._options = None
  _ORCALOADREPORT.fields_by_name['rps']._serialized_options = b'\030\001'
  _ORCALOADREPORT.fields_by_name['utilization']._options = None
  _ORCALOADREPORT.fields_by_name['utilization']._serialized_options = b'\372B\031\232\001\026*\024\022\022\031\000\000\000\000\000\000\360?)\000\000\000\000\000\000\000\000'
  _ORCALOADREPORT.fields_by_name['rps_fractional']._options = None
  _ORCALOADREPORT.fields_by_name['rps_fractional']._serialized_options = b'\372B\013\022\t)\000\000\000\000\000\000\000\000'
  _ORCALOADREPORT.fields_by_name['eps']._options = None
  _ORCALOADREPORT.fields_by_name['eps']._serialized_options = b'\372B\013\022\t)\000\000\000\000\000\000\000\000'
  _ORCALOADREPORT.fields_by_name['application_utilization']._options = None
  _ORCALOADREPORT.fields_by_name['application_utilization']._serialized_options = b'\372B\013\022\t)\000\000\000\000\000\000\000\000'
  _globals['_ORCALOADREPORT']._serialized_start=87
  _globals['_ORCALOADREPORT']._serialized_end=736
  _globals['_ORCALOADREPORT_REQUESTCOSTENTRY']._serialized_start=581
  _globals['_ORCALOADREPORT_REQUESTCOSTENTRY']._serialized_end=631
  _globals['_ORCALOADREPORT_UTILIZATIONENTRY']._serialized_start=633
  _globals['_ORCALOADREPORT_UTILIZATIONENTRY']._serialized_end=683
  _globals['_ORCALOADREPORT_NAMEDMETRICSENTRY']._serialized_start=685
  _globals['_ORCALOADREPORT_NAMEDMETRICSENTRY']._serialized_end=736
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/type/datetime.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1agoogle/type/datetime.proto\x12\x0bgoogle.type\x1a\x1egoogle/protobuf/duration.proto\"\xe0\x01\n\x08\x44\x61teTime\x12\x0c\n\x04year\x18\x01 \x01(\x05\x12\r\n\x05month\x18\x02 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x05\x12\r\n\x05hours\x18\x04 \x01(\x05\x12\x0f\n\x07minutes\x18\x05 \x01(\x05\x12\x0f\n\x07seconds\x18\x06 \x01(\x05\x12\r\n\x05nanos\x18\x07 \x01(\x05\x12/\n\nutc_offset\x18\x08 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x12*\n\ttime_zone\x18\t \x01(\x0b\x32\x15.google.type.TimeZoneH\x00\x42\r\n\x0btime_offset\"\'\n\x08TimeZone\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\tBi\n\x0f\x63om.google.typeB\rDateTimeProtoP\x01Z<google.golang.org/genproto/googleapis/type/datetime;datetime\xf8\x01\x01\xa2\x02\x03GTPb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.type.datetime_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017com.google.typeB\rDateTimeProtoP\001Z<google.golang.org/genproto/googleapis/type/datetime;datetime\370\001\001\242\002\003GTP'
  _globals['_DATETIME']._serialized_start=76
  _globals['_DATETIME']._serialized_end=300
  _globals['_TIMEZONE']._serialized_start=302
  _globals['_TIMEZONE']._serialized_end=341
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from envoy.service.accesslog.v3 import als_pb2 as envoy_dot_service_dot_accesslog_dot_v3_dot_als__pb2


class AccessLogServiceStub(object):
    """[#protodoc-title: gRPC access log service (ALS)]

    Service for streaming access logs from Envoy to an access log server.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StreamAccessLogs = channel.stream_unary(
                '/envoy.service.accesslog.v3.AccessLogService/StreamAccessLogs',
                request_serializer=envoy_dot_service_dot_accesslog_dot_v3_dot_als__pb2.StreamAccessLogsMessage.SerializeToString,
                response_deserializer=envoy_dot_service_dot_accesslog_dot_v3_dot_als__pb2.StreamAccessLogsResponse.FromString,
                )


class AccessLogServiceServicer(object):
    """[#protodoc-title: gRPC access log service (ALS)]

    Service for streaming access logs from Envoy to an access log server.
    """

    def StreamAccessLogs(self, request_iterator, context):
        """Envoy will connect and send StreamAccessLogsMessage messages forever. It does not expect any
        response to be sent as nothing would be done in the case of failure. The server should
        disconnect if it expects Envoy to reconnect. In the future we may decide to add a different
        API for "critical" access logs in which Envoy will buffer access logs for some period of time
        until it gets an ACK so it could then retry. This API is designed for high throughput with the
        expectation that it might be lossy.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AccessLogServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StreamAccessLogs': grpc.stream_unary_rpc_method_handler(
                    servicer.StreamAccessLogs,
                    request_deserializer=envoy_dot_service_dot_accesslog_dot_v3_dot_als__pb2.StreamAccessLogsMessage.FromString,
                    response_serializer=envoy_dot_service_dot_accesslog_dot_v3_dot_als__pb2.StreamAccessLogsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'envoy.service.accesslog.v3.AccessLogService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AccessLogService(object):
    """[#protodoc-title: gRPC access log service (ALS)]

    Service for streaming access logs from Envoy to an access log server.
    """

    @staticmethod
    def StreamAccessLogs(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/envoy.service.accesslog.v3.AccessLogService/StreamAccessLogs',
            envoy_dot_service_dot_accesslog_dot_v3_dot_als__pb2.StreamAccessLogsMessage.SerializeToString,
            envoy_dot_service_dot_accesslog_dot_v3_dot_als__pb2.StreamAccessLogsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/internal_redirect/allow_listed_routes/v3/allow_listed_routes_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nZenvoy/extensions/internal_redirect/allow_listed_routes/v3/allow_listed_routes_config.proto\x12\x39\x65nvoy.extensions.internal_redirect.allow_listed_routes.v3\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"D\n\x17\x41llowListedRoutesConfig\x12)\n\x13\x61llowed_route_names\x18\x01 \x03(\tB\x0c\xfa\x42\t\x92\x01\x06\"\x04r\x02\x10\x01\x42\xe9\x01\nGio.envoyproxy.envoy.extensions.internal_redirect.allow_listed_routes.v3B\x1c\x41llowListedRoutesConfigProtoP\x01Zvgithub.com/envoyproxy/go-control-plane/envoy/extensions/internal_redirect/allow_listed_routes/v3;allow_listed_routesv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.internal_redirect.allow_listed_routes.v3.allow_listed_routes_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nGio.envoyproxy.envoy.extensions.internal_redirect.allow_listed_routes.v3B\034AllowListedRoutesConfigProtoP\001Zvgithub.com/envoyproxy/go-control-plane/envoy/extensions/internal_redirect/allow_listed_routes/v3;allow_listed_routesv3\272\200\310\321\006\002\020\002'
  _ALLOWLISTEDROUTESCONFIG.fields_by_name['allowed_route_names']._options = None
  _ALLOWLISTEDROUTESCONFIG.fields_by_name['allowed_route_names']._serialized_options = b'\372B\t\222\001\006\"\004r\002\020\001'
  _globals['_ALLOWLISTEDROUTESCONFIG']._serialized_start=209
  _globals['_ALLOWLISTEDROUTESCONFIG']._serialized_end=277
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/core/http_uri.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n envoy/api/v2/core/http_uri.proto\x12\x11\x65nvoy.api.v2.core\x1a\x1egoogle/protobuf/duration.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x8e\x01\n\x07HttpUri\x12\x14\n\x03uri\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x1a\n\x07\x63luster\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01H\x00\x12\x36\n\x07timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01\x32\x00\x42\x19\n\x12http_upstream_type\x12\x03\xf8\x42\x01\x42\x8f\x01\n\x1fio.envoyproxy.envoy.api.v2.coreB\x0cHttpUriProtoP\x01Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65nvoy.config.core.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.core.http_uri_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.envoyproxy.envoy.api.v2.coreB\014HttpUriProtoP\001Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\362\230\376\217\005\026\022\024envoy.config.core.v3\272\200\310\321\006\002\020\001'
  _HTTPURI.oneofs_by_name['http_upstream_type']._options = None
  _HTTPURI.oneofs_by_name['http_upstream_type']._serialized_options = b'\370B\001'
  _HTTPURI.fields_by_name['uri']._options = None
  _HTTPURI.fields_by_name['uri']._serialized_options = b'\372B\004r\002 \001'
  _HTTPURI.fields_by_name['cluster']._options = None
  _HTTPURI.fields_by_name['cluster']._serialized_options = b'\372B\004r\002 \001'
  _HTTPURI.fields_by_name['timeout']._options = None
  _HTTPURI.fields_by_name['timeout']._serialized_options = b'\372B\007\252\001\004\010\0012\000'
  _globals['_HTTPURI']._serialized_start=176
  _globals['_HTTPURI']._serialized_end=318
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/kill_request/v3/kill_request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@envoy/extensions/filters/http/kill_request/v3/kill_request.proto\x12-envoy.extensions.filters.http.kill_request.v3\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xf9\x01\n\x0bKillRequest\x12\x35\n\x0bprobability\x18\x01 \x01(\x0b\x32 .envoy.type.v3.FractionalPercent\x12(\n\x13kill_request_header\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00\x12\x61\n\tdirection\x18\x03 \x01(\x0e\x32\x44.envoy.extensions.filters.http.kill_request.v3.KillRequest.DirectionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"&\n\tDirection\x12\x0b\n\x07REQUEST\x10\x00\x12\x0c\n\x08RESPONSE\x10\x01\x42\xbe\x01\n;io.envoyproxy.envoy.extensions.filters.http.kill_request.v3B\x10KillRequestProtoP\x01Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/kill_request/v3;kill_requestv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.kill_request.v3.kill_request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n;io.envoyproxy.envoy.extensions.filters.http.kill_request.v3B\020KillRequestProtoP\001Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/kill_request/v3;kill_requestv3\272\200\310\321\006\002\020\002'
  _KILLREQUEST.fields_by_name['kill_request_header']._options = None
  _KILLREQUEST.fields_by_name['kill_request_header']._serialized_options = b'\372B\010r\006\300\001\002\310\001\000'
  _KILLREQUEST.fields_by_name['direction']._options = None
  _KILLREQUEST.fields_by_name['direction']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_KILLREQUEST']._serialized_start=201
  _globals['_KILLREQUEST']._serialized_end=450
  _globals['_KILLREQUEST_DIRECTION']._serialized_start=412
  _globals['_KILLREQUEST_DIRECTION']._serialized_end=450
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/direct_response/v3/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@envoy/extensions/filters/network/direct_response/v3/config.proto\x12\x33\x65nvoy.extensions.filters.network.direct_response.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"z\n\x06\x43onfig\x12\x32\n\x08response\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSource:<\x9a\xc5\x88\x1e\x37\n5envoy.config.filter.network.direct_response.v2.ConfigB\xc8\x01\nAio.envoyproxy.envoy.extensions.filters.network.direct_response.v3B\x0b\x43onfigProtoP\x01Zlgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/direct_response/v3;direct_responsev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.direct_response.v3.config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nAio.envoyproxy.envoy.extensions.filters.network.direct_response.v3B\013ConfigProtoP\001Zlgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/direct_response/v3;direct_responsev3\272\200\310\321\006\002\020\002'
  _CONFIG._options = None
  _CONFIG._serialized_options = b'\232\305\210\0367\n5envoy.config.filter.network.direct_response.v2.Config'
  _globals['_CONFIG']._serialized_start=220
  _globals['_CONFIG']._serialized_end=342
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/range.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x65nvoy/type/range.proto\x12\nenvoy.type\x1a\x1dudpa/annotations/status.proto\"(\n\nInt64Range\x12\r\n\x05start\x18\x01 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x03\"(\n\nInt32Range\x12\r\n\x05start\x18\x01 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x05\")\n\x0b\x44oubleRange\x12\r\n\x05start\x18\x01 \x01(\x01\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x01\x42\x63\n\x18io.envoyproxy.envoy.typeB\nRangeProtoP\x01Z1github.com/envoyproxy/go-control-plane/envoy/type\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.range_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030io.envoyproxy.envoy.typeB\nRangeProtoP\001Z1github.com/envoyproxy/go-control-plane/envoy/type\272\200\310\321\006\002\020\001'
  _globals['_INT64RANGE']._serialized_start=69
  _globals['_INT64RANGE']._serialized_end=109
  _globals['_INT32RANGE']._serialized_start=111
  _globals['_INT32RANGE']._serialized_end=151
  _globals['_DOUBLERANGE']._serialized_start=153
  _globals['_DOUBLERANGE']._serialized_end=194
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/ip_tagging/v2/ip_tagging.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7envoy/config/filter/http/ip_tagging/v2/ip_tagging.proto\x12&envoy.config.filter.http.ip_tagging.v2\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc0\x02\n\tIPTagging\x12]\n\x0crequest_type\x18\x01 \x01(\x0e\x32=.envoy.config.filter.http.ip_tagging.v2.IPTagging.RequestTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12R\n\x07ip_tags\x18\x04 \x03(\x0b\x32\x37.envoy.config.filter.http.ip_tagging.v2.IPTagging.IPTagB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1aK\n\x05IPTag\x12\x13\n\x0bip_tag_name\x18\x01 \x01(\t\x12-\n\x07ip_list\x18\x02 \x03(\x0b\x32\x1c.envoy.api.v2.core.CidrRange\"3\n\x0bRequestType\x12\x08\n\x04\x42OTH\x10\x00\x12\x0c\n\x08INTERNAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\x42\xdf\x01\n4io.envoyproxy.envoy.config.filter.http.ip_tagging.v2B\x0eIpTaggingProtoP\x01ZZgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/ip_tagging/v2;ip_taggingv2\xf2\x98\xfe\x8f\x05-\x12+envoy.extensions.filters.http.ip_tagging.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.http.ip_tagging.v2.ip_tagging_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4io.envoyproxy.envoy.config.filter.http.ip_tagging.v2B\016IpTaggingProtoP\001ZZgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/ip_tagging/v2;ip_taggingv2\362\230\376\217\005-\022+envoy.extensions.filters.http.ip_tagging.v3\272\200\310\321\006\002\020\001'
  _IPTAGGING.fields_by_name['request_type']._options = None
  _IPTAGGING.fields_by_name['request_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _IPTAGGING.fields_by_name['ip_tags']._options = None
  _IPTAGGING.fields_by_name['ip_tags']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_IPTAGGING']._serialized_start=221
  _globals['_IPTAGGING']._serialized_end=541
  _globals['_IPTAGGING_IPTAG']._serialized_start=413
  _globals['_IPTAGGING_IPTAG']._serialized_end=488
  _globals['_IPTAGGING_REQUESTTYPE']._serialized_start=490
  _globals['_IPTAGGING_REQUESTTYPE']._serialized_end=541
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/access_loggers/grpc/v3/als.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import config_source_pb2 as envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2
from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from envoy.type.tracing.v3 import custom_tag_pb2 as envoy_dot_type_dot_tracing_dot_v3_dot_custom__tag__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1envoy/extensions/access_loggers/grpc/v3/als.proto\x12\'envoy.extensions.access_loggers.grpc.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a(envoy/config/core/v3/config_source.proto\x1a\'envoy/config/core/v3/grpc_service.proto\x1a&envoy/type/tracing/v3/custom_tag.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xbc\x02\n\x17HttpGrpcAccessLogConfig\x12\x63\n\rcommon_config\x18\x01 \x01(\x0b\x32\x42.envoy.extensions.access_loggers.grpc.v3.CommonGrpcAccessLogConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12)\n!additional_request_headers_to_log\x18\x02 \x03(\t\x12*\n\"additional_response_headers_to_log\x18\x03 \x03(\t\x12+\n#additional_response_trailers_to_log\x18\x04 \x03(\t:8\x9a\xc5\x88\x1e\x33\n1envoy.config.accesslog.v2.HttpGrpcAccessLogConfig\"\xb6\x01\n\x16TcpGrpcAccessLogConfig\x12\x63\n\rcommon_config\x18\x01 \x01(\x0b\x32\x42.envoy.extensions.access_loggers.grpc.v3.CommonGrpcAccessLogConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:7\x9a\xc5\x88\x1e\x32\n0envoy.config.accesslog.v2.TcpGrpcAccessLogConfig\"\x9e\x04\n\x19\x43ommonGrpcAccessLogConfig\x12\x19\n\x08log_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x41\n\x0cgrpc_service\x18\x02 \x01(\x0b\x32!.envoy.config.core.v3.GrpcServiceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12I\n\x15transport_api_version\x18\x06 \x01(\x0e\x32 .envoy.config.core.v3.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x42\n\x15\x62uffer_flush_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x37\n\x11\x62uffer_size_bytes\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12#\n\x1b\x66ilter_state_objects_to_log\x18\x05 \x03(\t\x12\x43\n\x18grpc_stream_retry_policy\x18\x07 \x01(\x0b\x32!.envoy.config.core.v3.RetryPolicy\x12\x35\n\x0b\x63ustom_tags\x18\x08 \x03(\x0b\x32 .envoy.type.tracing.v3.CustomTag::\x9a\xc5\x88\x1e\x35\n3envoy.config.accesslog.v2.CommonGrpcAccessLogConfigB\xa2\x01\n5io.envoyproxy.envoy.extensions.access_loggers.grpc.v3B\x08\x41lsProtoP\x01ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/access_loggers/grpc/v3;grpcv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.access_loggers.grpc.v3.als_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n5io.envoyproxy.envoy.extensions.access_loggers.grpc.v3B\010AlsProtoP\001ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/access_loggers/grpc/v3;grpcv3\272\200\310\321\006\002\020\002'
  _HTTPGRPCACCESSLOGCONFIG.fields_by_name['common_config']._options = None
  _HTTPGRPCACCESSLOGCONFIG.fields_by_name['common_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _HTTPGRPCACCESSLOGCONFIG._options = None
  _HTTPGRPCACCESSLOGCONFIG._serialized_options = b'\232\305\210\0363\n1envoy.config.accesslog.v2.HttpGrpcAccessLogConfig'
  _TCPGRPCACCESSLOGCONFIG.fields_by_name['common_config']._options = None
  _TCPGRPCACCESSLOGCONFIG.fields_by_name['common_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TCPGRPCACCESSLOGCONFIG._options = None
  _TCPGRPCACCESSLOGCONFIG._serialized_options = b'\232\305\210\0362\n0envoy.config.accesslog.v2.TcpGrpcAccessLogConfig'
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['log_name']._options = None
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['log_name']._serialized_options = b'\372B\004r\002\020\001'
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['grpc_service']._options = None
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['grpc_service']._serialized_options = b'\372B\005\212\001\002\020\001'
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['transport_api_version']._options = None
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['transport_api_version']._serialized_options = b'\372B\005\202\001\002\020\001'
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['buffer_flush_interval']._options = None
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['buffer_flush_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _COMMONGRPCACCESSLOGCONFIG._options = None
  _COMMONGRPCACCESSLOGCONFIG._serialized_options = b'\232\305\210\0365\n3envoy.config.accesslog.v2.CommonGrpcAccessLogConfig'
  _globals['_HTTPGRPCACCESSLOGCONFIG']._serialized_start=406
  _globals['_HTTPGRPCACCESSLOGCONFIG']._serialized_end=722
  _globals['_TCPGRPCACCESSLOGCONFIG']._serialized_start=725
  _globals['_TCPGRPCACCESSLOGCONFIG']._serialized_end=907
  _globals['_COMMONGRPCACCESSLOGCONFIG']._serialized_start=910
  _globals['_COMMONGRPCACCESSLOGCONFIG']._serialized_end=1452
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/udp_socket_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,envoy/config/core/v3/udp_socket_config.proto\x12\x14\x65nvoy.config.core.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x8a\x01\n\x0fUdpSocketConfig\x12G\n\x14max_rx_datagram_size\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueB\x0b\xfa\x42\x08\x32\x06\x10\x80\x80\x04 \x00\x12.\n\nprefer_gro\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x88\x01\n\"io.envoyproxy.envoy.config.core.v3B\x14UdpSocketConfigProtoP\x01ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.core.v3.udp_socket_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"io.envoyproxy.envoy.config.core.v3B\024UdpSocketConfigProtoP\001ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\272\200\310\321\006\002\020\002'
  _UDPSOCKETCONFIG.fields_by_name['max_rx_datagram_size']._options = None
  _UDPSOCKETCONFIG.fields_by_name['max_rx_datagram_size']._serialized_options = b'\372B\0102\006\020\200\200\004 \000'
  _globals['_UDPSOCKETCONFIG']._serialized_start=159
  _globals['_UDPSOCKETCONFIG']._serialized_end=297
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/fault/v2/fault.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.route import route_components_pb2 as envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2
from envoy.config.filter.fault.v2 import fault_pb2 as envoy_dot_config_dot_filter_dot_fault_dot_v2_dot_fault__pb2
from envoy.type import percent_pb2 as envoy_dot_type_dot_percent__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-envoy/config/filter/http/fault/v2/fault.proto\x12!envoy.config.filter.http.fault.v2\x1a)envoy/api/v2/route/route_components.proto\x1a(envoy/config/filter/fault/v2/fault.proto\x1a\x18\x65nvoy/type/percent.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xde\x01\n\nFaultAbort\x12\"\n\x0bhttp_status\x18\x02 \x01(\rB\x0b\xfa\x42\x08*\x06\x10\xd8\x04(\xc8\x01H\x00\x12Q\n\x0cheader_abort\x18\x04 \x01(\x0b\x32\x39.envoy.config.filter.http.fault.v2.FaultAbort.HeaderAbortH\x00\x12\x31\n\npercentage\x18\x03 \x01(\x0b\x32\x1d.envoy.type.FractionalPercent\x1a\r\n\x0bHeaderAbortB\x11\n\nerror_type\x12\x03\xf8\x42\x01J\x04\x08\x01\x10\x02\"\xbf\x04\n\tHTTPFault\x12\x37\n\x05\x64\x65lay\x18\x01 \x01(\x0b\x32(.envoy.config.filter.fault.v2.FaultDelay\x12<\n\x05\x61\x62ort\x18\x02 \x01(\x0b\x32-.envoy.config.filter.http.fault.v2.FaultAbort\x12\x18\n\x10upstream_cluster\x18\x03 \x01(\t\x12\x32\n\x07headers\x18\x04 \x03(\x0b\x32!.envoy.api.v2.route.HeaderMatcher\x12\x18\n\x10\x64ownstream_nodes\x18\x05 \x03(\t\x12\x37\n\x11max_active_faults\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12I\n\x13response_rate_limit\x18\x07 \x01(\x0b\x32,.envoy.config.filter.fault.v2.FaultRateLimit\x12\x1d\n\x15\x64\x65lay_percent_runtime\x18\x08 \x01(\t\x12\x1d\n\x15\x61\x62ort_percent_runtime\x18\t \x01(\t\x12\x1e\n\x16\x64\x65lay_duration_runtime\x18\n \x01(\t\x12!\n\x19\x61\x62ort_http_status_runtime\x18\x0b \x01(\t\x12!\n\x19max_active_faults_runtime\x18\x0c \x01(\t\x12+\n#response_rate_limit_percent_runtime\x18\r \x01(\tB\xc7\x01\n/io.envoyproxy.envoy.config.filter.http.fault.v2B\nFaultProtoP\x01ZPgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/fault/v2;faultv2\xf2\x98\xfe\x8f\x05(\x12&envoy.extensions.filters.http.fault.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.http.fault.v2.fault_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n/io.envoyproxy.envoy.config.filter.http.fault.v2B\nFaultProtoP\001ZPgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/fault/v2;faultv2\362\230\376\217\005(\022&envoy.extensions.filters.http.fault.v3\272\200\310\321\006\002\020\001'
  _FAULTABORT.oneofs_by_name['error_type']._options = None
  _FAULTABORT.oneofs_by_name['error_type']._serialized_options = b'\370B\001'
  _FAULTABORT.fields_by_name['http_status']._options = None
  _FAULTABORT.fields_by_name['http_status']._serialized_options = b'\372B\010*\006\020\330\004(\310\001'
  _globals['_FAULTABORT']._serialized_start=316
  _globals['_FAULTABORT']._serialized_end=538
  _globals['_FAULTABORT_HEADERABORT']._serialized_start=500
  _globals['_FAULTABORT_HEADERABORT']._serialized_end=513
  _globals['_HTTPFAULT']._serialized_start=541
  _globals['_HTTPFAULT']._serialized_end=1116
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/grpc_http1_reverse_bridge/v3/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGenvoy/extensions/filters/http/grpc_http1_reverse_bridge/v3/config.proto\x12:envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xc7\x01\n\x0c\x46ilterConfig\x12\x1d\n\x0c\x63ontent_type\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1c\n\x14withhold_grpc_frames\x18\x02 \x01(\x08\x12)\n\x14response_size_header\x18\x03 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xc8\x01\x00:O\x9a\xc5\x88\x1eJ\nHenvoy.config.filter.http.grpc_http1_reverse_bridge.v2alpha1.FilterConfig\"\x81\x01\n\x14\x46ilterConfigPerRoute\x12\x10\n\x08\x64isabled\x18\x01 \x01(\x08:W\x9a\xc5\x88\x1eR\nPenvoy.config.filter.http.grpc_http1_reverse_bridge.v2alpha1.FilterConfigPerRouteB\xe0\x01\nHio.envoyproxy.envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3B\x0b\x43onfigProtoP\x01Z}github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/grpc_http1_reverse_bridge/v3;grpc_http1_reverse_bridgev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3.config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nHio.envoyproxy.envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3B\013ConfigProtoP\001Z}github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/grpc_http1_reverse_bridge/v3;grpc_http1_reverse_bridgev3\272\200\310\321\006\002\020\002'
  _FILTERCONFIG.fields_by_name['content_type']._options = None
  _FILTERCONFIG.fields_by_name['content_type']._serialized_options = b'\372B\004r\002\020\001'
  _FILTERCONFIG.fields_by_name['response_size_header']._options = None
  _FILTERCONFIG.fields_by_name['response_size_header']._serialized_options = b'\372B\010r\006\300\001\001\310\001\000'
  _FILTERCONFIG._options = None
  _FILTERCONFIG._serialized_options = b'\232\305\210\036J\nHenvoy.config.filter.http.grpc_http1_reverse_bridge.v2alpha1.FilterConfig'
  _FILTERCONFIGPERROUTE._options = None
  _FILTERCONFIGPERROUTE._serialized_options = b'\232\305\210\036R\nPenvoy.config.filter.http.grpc_http1_reverse_bridge.v2alpha1.FilterConfigPerRoute'
  _globals['_FILTERCONFIG']._serialized_start=227
  _globals['_FILTERCONFIG']._serialized_end=426
  _globals['_FILTERCONFIGPERROUTE']._serialized_start=429
  _globals['_FILTERCONFIGPERROUTE']._serialized_end=558
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/rbac/v3/rbac.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.rbac.v3 import rbac_pb2 as envoy_dot_config_dot_rbac_dot_v3_dot_rbac__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from xds.type.matcher.v3 import matcher_pb2 as xds_dot_type_dot_matcher_dot_v3_dot_matcher__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0envoy/extensions/filters/http/rbac/v3/rbac.proto\x12%envoy.extensions.filters.http.rbac.v3\x1a\x1f\x65nvoy/config/rbac/v3/rbac.proto\x1a\x1fxds/annotations/v3/status.proto\x1a!xds/type/matcher/v3/matcher.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\x9a\x03\n\x04RBAC\x12\x42\n\x05rules\x18\x01 \x01(\x0b\x32\x1a.envoy.config.rbac.v3.RBACB\x17\xf2\x98\xfe\x8f\x05\x11\x12\x0frules_specifier\x12N\n\x07matcher\x18\x04 \x01(\x0b\x32\x1c.xds.type.matcher.v3.MatcherB\x1f\xf2\x98\xfe\x8f\x05\x11\x12\x0frules_specifier\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x12P\n\x0cshadow_rules\x18\x02 \x01(\x0b\x32\x1a.envoy.config.rbac.v3.RBACB\x1e\xf2\x98\xfe\x8f\x05\x18\x12\x16shadow_rules_specifier\x12\\\n\x0eshadow_matcher\x18\x05 \x01(\x0b\x32\x1c.xds.type.matcher.v3.MatcherB&\xf2\x98\xfe\x8f\x05\x18\x12\x16shadow_rules_specifier\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x12 \n\x18shadow_rules_stat_prefix\x18\x03 \x01(\t:,\x9a\xc5\x88\x1e\'\n%envoy.config.filter.http.rbac.v2.RBAC\"\x85\x01\n\x0cRBACPerRoute\x12\x39\n\x04rbac\x18\x02 \x01(\x0b\x32+.envoy.extensions.filters.http.rbac.v3.RBAC:4\x9a\xc5\x88\x1e/\n-envoy.config.filter.http.rbac.v2.RBACPerRouteJ\x04\x08\x01\x10\x02\x42\x9f\x01\n3io.envoyproxy.envoy.extensions.filters.http.rbac.v3B\tRbacProtoP\x01ZSgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/rbac/v3;rbacv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.rbac.v3.rbac_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n3io.envoyproxy.envoy.extensions.filters.http.rbac.v3B\tRbacProtoP\001ZSgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/rbac/v3;rbacv3\272\200\310\321\006\002\020\002'
  _RBAC.fields_by_name['rules']._options = None
  _RBAC.fields_by_name['rules']._serialized_options = b'\362\230\376\217\005\021\022\017rules_specifier'
  _RBAC.fields_by_name['matcher']._options = None
  _RBAC.fields_by_name['matcher']._serialized_options = b'\362\230\376\217\005\021\022\017rules_specifier\322\306\244\341\006\002\010\001'
  _RBAC.fields_by_name['shadow_rules']._options = None
  _RBAC.fields_by_name['shadow_rules']._serialized_options = b'\362\230\376\217\005\030\022\026shadow_rules_specifier'
  _RBAC.fields_by_name['shadow_matcher']._options = None
  _RBAC.fields_by_name['shadow_matcher']._serialized_options = b'\362\230\376\217\005\030\022\026shadow_rules_specifier\322\306\244\341\006\002\010\001'
  _RBAC._options = None
  _RBAC._serialized_options = b'\232\305\210\036\'\n%envoy.config.filter.http.rbac.v2.RBAC'
  _RBACPERROUTE._options = None
  _RBACPERROUTE._serialized_options = b'\232\305\210\036/\n-envoy.config.filter.http.rbac.v2.RBACPerRoute'
  _globals['_RBAC']._serialized_start=291
  _globals['_RBAC']._serialized_end=701
  _globals['_RBACPERROUTE']._serialized_start=704
  _globals['_RBACPERROUTE']._serialized_end=837
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/trace/v2alpha/xray.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%envoy/config/trace/v2alpha/xray.proto\x12\x1a\x65nvoy.config.trace.v2alpha\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa5\x01\n\nXRayConfig\x12\x39\n\x0f\x64\x61\x65mon_endpoint\x18\x01 \x01(\x0b\x32 .envoy.api.v2.core.SocketAddress\x12\x1d\n\x0csegment_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12=\n\x16sampling_rule_manifest\x18\x03 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x82\x01\n(io.envoyproxy.envoy.config.trace.v2alphaB\tXrayProtoP\x01ZAgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v2alpha\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.trace.v2alpha.xray_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(io.envoyproxy.envoy.config.trace.v2alphaB\tXrayProtoP\001ZAgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v2alpha\272\200\310\321\006\002\020\001'
  _XRAYCONFIG.fields_by_name['segment_name']._options = None
  _XRAYCONFIG.fields_by_name['segment_name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_XRAYCONFIG']._serialized_start=189
  _globals['_XRAYCONFIG']._serialized_end=354
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/cluster/redis/redis_cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.envoy/config/cluster/redis/redis_cluster.proto\x12\x1a\x65nvoy.config.cluster.redis\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xe9\x02\n\x12RedisClusterConfig\x12\x41\n\x14\x63luster_refresh_rate\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x44\n\x17\x63luster_refresh_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12<\n\x19redirect_refresh_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12@\n\x1aredirect_refresh_threshold\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12!\n\x19\x66\x61ilure_refresh_threshold\x18\x05 \x01(\r\x12\'\n\x1fhost_degraded_refresh_threshold\x18\x06 \x01(\rB\x8a\x01\n(io.envoyproxy.envoy.config.cluster.redisB\x11RedisClusterProtoP\x01ZAgithub.com/envoyproxy/go-control-plane/envoy/config/cluster/redis\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.cluster.redis.redis_cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(io.envoyproxy.envoy.config.cluster.redisB\021RedisClusterProtoP\001ZAgithub.com/envoyproxy/go-control-plane/envoy/config/cluster/redis\272\200\310\321\006\002\020\001'
  _REDISCLUSTERCONFIG.fields_by_name['cluster_refresh_rate']._options = None
  _REDISCLUSTERCONFIG.fields_by_name['cluster_refresh_rate']._serialized_options = b'\372B\005\252\001\002*\000'
  _REDISCLUSTERCONFIG.fields_by_name['cluster_refresh_timeout']._options = None
  _REDISCLUSTERCONFIG.fields_by_name['cluster_refresh_timeout']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_REDISCLUSTERCONFIG']._serialized_start=199
  _globals['_REDISCLUSTERCONFIG']._serialized_end=560
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/endpoint/v3/load_report.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*envoy/config/endpoint/v3/load_report.proto\x12\x18\x65nvoy.config.endpoint.v3\x1a\"envoy/config/core/v3/address.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb3\x03\n\x15UpstreamLocalityStats\x12\x30\n\x08locality\x18\x01 \x01(\x0b\x32\x1e.envoy.config.core.v3.Locality\x12!\n\x19total_successful_requests\x18\x02 \x01(\x04\x12\"\n\x1atotal_requests_in_progress\x18\x03 \x01(\x04\x12\x1c\n\x14total_error_requests\x18\x04 \x01(\x04\x12\x1d\n\x15total_issued_requests\x18\x08 \x01(\x04\x12L\n\x11load_metric_stats\x18\x05 \x03(\x0b\x32\x31.envoy.config.endpoint.v3.EndpointLoadMetricStats\x12P\n\x17upstream_endpoint_stats\x18\x07 \x03(\x0b\x32/.envoy.config.endpoint.v3.UpstreamEndpointStats\x12\x10\n\x08priority\x18\x06 \x01(\r:2\x9a\xc5\x88\x1e-\n+envoy.api.v2.endpoint.UpstreamLocalityStats\"\xf8\x02\n\x15UpstreamEndpointStats\x12.\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1d.envoy.config.core.v3.Address\x12)\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12!\n\x19total_successful_requests\x18\x02 \x01(\x04\x12\"\n\x1atotal_requests_in_progress\x18\x03 \x01(\x04\x12\x1c\n\x14total_error_requests\x18\x04 \x01(\x04\x12\x1d\n\x15total_issued_requests\x18\x07 \x01(\x04\x12L\n\x11load_metric_stats\x18\x05 \x03(\x0b\x32\x31.envoy.config.endpoint.v3.EndpointLoadMetricStats:2\x9a\xc5\x88\x1e-\n+envoy.api.v2.endpoint.UpstreamEndpointStats\"\xab\x01\n\x17\x45ndpointLoadMetricStats\x12\x13\n\x0bmetric_name\x18\x01 \x01(\t\x12)\n!num_requests_finished_with_metric\x18\x02 \x01(\x04\x12\x1a\n\x12total_metric_value\x18\x03 \x01(\x01:4\x9a\xc5\x88\x1e/\n-envoy.api.v2.endpoint.EndpointLoadMetricStats\"\xfd\x03\n\x0c\x43lusterStats\x12\x1d\n\x0c\x63luster_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1c\n\x14\x63luster_service_name\x18\x06 \x01(\t\x12Z\n\x17upstream_locality_stats\x18\x02 \x03(\x0b\x32/.envoy.config.endpoint.v3.UpstreamLocalityStatsB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x1e\n\x16total_dropped_requests\x18\x03 \x01(\x04\x12P\n\x10\x64ropped_requests\x18\x05 \x03(\x0b\x32\x36.envoy.config.endpoint.v3.ClusterStats.DroppedRequests\x12\x37\n\x14load_report_interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x1a~\n\x0f\x44roppedRequests\x12\x19\n\x08\x63\x61tegory\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\rdropped_count\x18\x02 \x01(\x04:9\x9a\xc5\x88\x1e\x34\n2envoy.api.v2.endpoint.ClusterStats.DroppedRequests:)\x9a\xc5\x88\x1e$\n\"envoy.api.v2.endpoint.ClusterStatsB\x8f\x01\n&io.envoyproxy.envoy.config.endpoint.v3B\x0fLoadReportProtoP\x01ZJgithub.com/envoyproxy/go-control-plane/envoy/config/endpoint/v3;endpointv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.endpoint.v3.load_report_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&io.envoyproxy.envoy.config.endpoint.v3B\017LoadReportProtoP\001ZJgithub.com/envoyproxy/go-control-plane/envoy/config/endpoint/v3;endpointv3\272\200\310\321\006\002\020\002'
  _UPSTREAMLOCALITYSTATS._options = None
  _UPSTREAMLOCALITYSTATS._serialized_options = b'\232\305\210\036-\n+envoy.api.v2.endpoint.UpstreamLocalityStats'
  _UPSTREAMENDPOINTSTATS._options = None
  _UPSTREAMENDPOINTSTATS._serialized_options = b'\232\305\210\036-\n+envoy.api.v2.endpoint.UpstreamEndpointStats'
  _ENDPOINTLOADMETRICSTATS._options = None
  _ENDPOINTLOADMETRICSTATS._serialized_options = b'\232\305\210\036/\n-envoy.api.v2.endpoint.EndpointLoadMetricStats'
  _CLUSTERSTATS_DROPPEDREQUESTS.fields_by_name['category']._options = None
  _CLUSTERSTATS_DROPPEDREQUESTS.fields_by_name['category']._serialized_options = b'\372B\004r\002\020\001'
  _CLUSTERSTATS_DROPPEDREQUESTS._options = None
  _CLUSTERSTATS_DROPPEDREQUESTS._serialized_options = b'\232\305\210\0364\n2envoy.api.v2.endpoint.ClusterStats.DroppedRequests'
  _CLUSTERSTATS.fields_by_name['cluster_name']._options = None
  _CLUSTERSTATS.fields_by_name['cluster_name']._serialized_options = b'\372B\004r\002\020\001'
  _CLUSTERSTATS.fields_by_name['upstream_locality_stats']._options = None
  _CLUSTERSTATS.fields_by_name['upstream_locality_stats']._serialized_options = b'\372B\005\222\001\002\010\001'
  _CLUSTERSTATS._options = None
  _CLUSTERSTATS._serialized_options = b'\232\305\210\036$\n\"envoy.api.v2.endpoint.ClusterStats'
  _globals['_UPSTREAMLOCALITYSTATS']._serialized_start=295
  _globals['_UPSTREAMLOCALITYSTATS']._serialized_end=730
  _globals['_UPSTREAMENDPOINTSTATS']._serialized_start=733
  _globals['_UPSTREAMENDPOINTSTATS']._serialized_end=1109
  _globals['_ENDPOINTLOADMETRICSTATS']._serialized_start=1112
  _globals['_ENDPOINTLOADMETRICSTATS']._serialized_end=1283
  _globals['_CLUSTERSTATS']._serialized_start=1286
  _globals['_CLUSTERSTATS']._serialized_end=1795
  _globals['_CLUSTERSTATS_DROPPEDREQUESTS']._serialized_start=1626
  _globals['_CLUSTERSTATS_DROPPEDREQUESTS']._serialized_end=1752
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/buffer/v3/buffer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4envoy/extensions/filters/http/buffer/v3/buffer.proto\x12\'envoy.extensions.filters.http.buffer.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x87\x01\n\x06\x42uffer\x12\x45\n\x11max_request_bytes\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0c\xfa\x42\t*\x02 \x00\x8a\x01\x02\x10\x01:0\x9a\xc5\x88\x1e+\n)envoy.config.filter.http.buffer.v2.BufferJ\x04\x08\x02\x10\x03\"\xc5\x01\n\x0e\x42ufferPerRoute\x12\x1b\n\x08\x64isabled\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12K\n\x06\x62uffer\x18\x02 \x01(\x0b\x32/.envoy.extensions.filters.http.buffer.v3.BufferB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00:8\x9a\xc5\x88\x1e\x33\n1envoy.config.filter.http.buffer.v2.BufferPerRouteB\x0f\n\x08override\x12\x03\xf8\x42\x01\x42\xa7\x01\n5io.envoyproxy.envoy.extensions.filters.http.buffer.v3B\x0b\x42ufferProtoP\x01ZWgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/buffer/v3;bufferv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.buffer.v3.buffer_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n5io.envoyproxy.envoy.extensions.filters.http.buffer.v3B\013BufferProtoP\001ZWgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/buffer/v3;bufferv3\272\200\310\321\006\002\020\002'
  _BUFFER.fields_by_name['max_request_bytes']._options = None
  _BUFFER.fields_by_name['max_request_bytes']._serialized_options = b'\372B\t*\002 \000\212\001\002\020\001'
  _BUFFER._options = None
  _BUFFER._serialized_options = b'\232\305\210\036+\n)envoy.config.filter.http.buffer.v2.Buffer'
  _BUFFERPERROUTE.oneofs_by_name['override']._options = None
  _BUFFERPERROUTE.oneofs_by_name['override']._serialized_options = b'\370B\001'
  _BUFFERPERROUTE.fields_by_name['disabled']._options = None
  _BUFFERPERROUTE.fields_by_name['disabled']._serialized_options = b'\372B\004j\002\010\001'
  _BUFFERPERROUTE.fields_by_name['buffer']._options = None
  _BUFFERPERROUTE.fields_by_name['buffer']._serialized_options = b'\372B\005\212\001\002\020\001'
  _BUFFERPERROUTE._options = None
  _BUFFERPERROUTE._serialized_options = b'\232\305\210\0363\n1envoy.config.filter.http.buffer.v2.BufferPerRoute'
  _globals['_BUFFER']._serialized_start=221
  _globals['_BUFFER']._serialized_end=356
  _globals['_BUFFERPERROUTE']._serialized_start=359
  _globals['_BUFFERPERROUTE']._serialized_end=556
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencensus/proto/resource/v1/resource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+opencensus/proto/resource/v1/resource.proto\x12\x1copencensus.proto.resource.v1\"\x8b\x01\n\x08Resource\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x42\n\x06labels\x18\x02 \x03(\x0b\x32\x32.opencensus.proto.resource.v1.Resource.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x98\x01\n\x1fio.opencensus.proto.resource.v1B\rResourceProtoP\x01ZEgithub.com/census-instrumentation/opencensus-proto/gen-go/resource/v1\xea\x02\x1cOpenCensus.Proto.Resource.V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opencensus.proto.resource.v1.resource_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.opencensus.proto.resource.v1B\rResourceProtoP\001ZEgithub.com/census-instrumentation/opencensus-proto/gen-go/resource/v1\352\002\034OpenCensus.Proto.Resource.V1'
  _RESOURCE_LABELSENTRY._options = None
  _RESOURCE_LABELSENTRY._serialized_options = b'8\001'
  _globals['_RESOURCE']._serialized_start=78
  _globals['_RESOURCE']._serialized_end=217
  _globals['_RESOURCE_LABELSENTRY']._serialized_start=172
  _globals['_RESOURCE_LABELSENTRY']._serialized_end=217
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/cluster/aggregate/v2alpha/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4envoy/config/cluster/aggregate/v2alpha/cluster.proto\x12&envoy.config.cluster.aggregate.v2alpha\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"+\n\rClusterConfig\x12\x1a\n\x08\x63lusters\x18\x01 \x03(\tB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x42\xcb\x01\n4io.envoyproxy.envoy.config.cluster.aggregate.v2alphaB\x0c\x43lusterProtoP\x01ZMgithub.com/envoyproxy/go-control-plane/envoy/config/cluster/aggregate/v2alpha\xf2\x98\xfe\x8f\x05(\x12&envoy.extensions.clusters.aggregate.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.cluster.aggregate.v2alpha.cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4io.envoyproxy.envoy.config.cluster.aggregate.v2alphaB\014ClusterProtoP\001ZMgithub.com/envoyproxy/go-control-plane/envoy/config/cluster/aggregate/v2alpha\362\230\376\217\005(\022&envoy.extensions.clusters.aggregate.v3\272\200\310\321\006\002\020\001'
  _CLUSTERCONFIG.fields_by_name['clusters']._options = None
  _CLUSTERCONFIG.fields_by_name['clusters']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_CLUSTERCONFIG']._serialized_start=184
  _globals['_CLUSTERCONFIG']._serialized_end=227
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/auth/v2alpha/external_auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.auth.v2 import external_auth_pb2 as envoy_dot_service_dot_auth_dot_v2_dot_external__auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.envoy/service/auth/v2alpha/external_auth.proto\x12\x1a\x65nvoy.service.auth.v2alpha\x1a)envoy/service/auth/v2/external_auth.proto2c\n\rAuthorization\x12R\n\x05\x43heck\x12#.envoy.service.auth.v2.CheckRequest\x1a$.envoy.service.auth.v2.CheckResponseB{\n(io.envoyproxy.envoy.service.auth.v2alphaB\nCertsProtoP\x01ZAgithub.com/envoyproxy/go-control-plane/envoy/service/auth/v2alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.auth.v2alpha.external_auth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(io.envoyproxy.envoy.service.auth.v2alphaB\nCertsProtoP\001ZAgithub.com/envoyproxy/go-control-plane/envoy/service/auth/v2alpha'
  _globals['_AUTHORIZATION']._serialized_start=121
  _globals['_AUTHORIZATION']._serialized_end=220
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/router/v3/router.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.accesslog.v3 import accesslog_pb2 as envoy_dot_config_dot_accesslog_dot_v3_dot_accesslog__pb2
from envoy.extensions.filters.network.http_connection_manager.v3 import http_connection_manager_pb2 as envoy_dot_extensions_dot_filters_dot_network_dot_http__connection__manager_dot_v3_dot_http__connection__manager__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4envoy/extensions/filters/http/router/v3/router.proto\x12\'envoy.extensions.filters.http.router.v3\x1a)envoy/config/accesslog/v3/accesslog.proto\x1aYenvoy/extensions/filters/network/http_connection_manager/v3/http_connection_manager.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xda\x06\n\x06Router\x12\x31\n\rdynamic_stats\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x18\n\x10start_child_span\x18\x02 \x01(\x08\x12:\n\x0cupstream_log\x18\x03 \x03(\x0b\x32$.envoy.config.accesslog.v3.AccessLog\x12\x66\n\x14upstream_log_options\x18\t \x01(\x0b\x32H.envoy.extensions.filters.http.router.v3.Router.UpstreamAccessLogOptions\x12\x1e\n\x16suppress_envoy_headers\x18\x04 \x01(\x08\x12\xb3\x01\n\x14strict_check_headers\x18\x05 \x03(\tB\x94\x01\xfa\x42\x90\x01\x92\x01\x8c\x01\"\x89\x01r\x86\x01R\x1ex-envoy-upstream-rq-timeout-msR&x-envoy-upstream-rq-per-try-timeout-msR\x13x-envoy-max-retriesR\x15x-envoy-retry-grpc-onR\x10x-envoy-retry-on\x12#\n\x1brespect_expected_rq_timeout\x18\x06 \x01(\x08\x12\x30\n(suppress_grpc_request_failure_code_stats\x18\x07 \x01(\x08\x12\x66\n\x15upstream_http_filters\x18\x08 \x03(\x0b\x32G.envoy.extensions.filters.network.http_connection_manager.v3.HttpFilter\x1a\x97\x01\n\x18UpstreamAccessLogOptions\x12-\n%flush_upstream_log_on_upstream_stream\x18\x01 \x01(\x08\x12L\n\x1bupstream_log_flush_interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xfa\x42\t\xaa\x01\x06\x32\x04\x10\xc0\x84=:0\x9a\xc5\x88\x1e+\n)envoy.config.filter.http.router.v2.RouterB\xa7\x01\n5io.envoyproxy.envoy.extensions.filters.http.router.v3B\x0bRouterProtoP\x01ZWgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/router/v3;routerv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.router.v3.router_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n5io.envoyproxy.envoy.extensions.filters.http.router.v3B\013RouterProtoP\001ZWgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/router/v3;routerv3\272\200\310\321\006\002\020\002'
  _ROUTER_UPSTREAMACCESSLOGOPTIONS.fields_by_name['upstream_log_flush_interval']._options = None
  _ROUTER_UPSTREAMACCESSLOGOPTIONS.fields_by_name['upstream_log_flush_interval']._serialized_options = b'\372B\t\252\001\0062\004\020\300\204='
  _ROUTER.fields_by_name['strict_check_headers']._options = None
  _ROUTER.fields_by_name['strict_check_headers']._serialized_options = b'\372B\220\001\222\001\214\001\"\211\001r\206\001R\036x-envoy-upstream-rq-timeout-msR&x-envoy-upstream-rq-per-try-timeout-msR\023x-envoy-max-retriesR\025x-envoy-retry-grpc-onR\020x-envoy-retry-on'
  _ROUTER._options = None
  _ROUTER._serialized_options = b'\232\305\210\036+\n)envoy.config.filter.http.router.v2.Router'
  _globals['_ROUTER']._serialized_start=387
  _globals['_ROUTER']._serialized_end=1245
  _globals['_ROUTER_UPSTREAMACCESSLOGOPTIONS']._serialized_start=1044
  _globals['_ROUTER_UPSTREAMACCESSLOGOPTIONS']._serialized_end=1195
# @@protoc_insertion_point(module_scope)
